@@ -12,6 +12,7 @@ A lightweight terminal spinner.
 
 from __future__ import absolute_import
 
+import contextlib
 import functools
 import itertools
 import signal
@@ -80,6 +81,7 @@ class Yaspin(object):
         self._spin_thread = None
         self._last_frame = None
         self._stdout_lock = threading.Lock()
+        self._hidden_level = 0
 
         # Signals
 
@@ -263,6 +265,20 @@ class Yaspin(object):
                 # can be rewritten to
                 sys.stdout.flush()
 
+    @contextlib.contextmanager
+    def hidden(self):
+        """Hide the spinner within a block, can be nested"""
+        if self._hidden_level == 0:
+            self.hide()
+        self._hidden_level += 1
+
+        try:
+            yield
+        finally:
+            self._hidden_level -= 1
+            if self._hidden_level == 0:
+                self.show()
+
     def show(self):
         """Show the hidden spinner."""
         thr_is_alive = self._spin_thread and self._spin_thread.is_alive()
@@ -336,7 +352,7 @@ class Yaspin(object):
                 sys.stdout.flush()
 
             # Wait
-            time.sleep(self._interval)
+            self._stop_spin.wait(self._interval)
 
     def _compose_color_func(self):
         fn = functools.partial(
